==> unicore-gateway-6.4.0-2.src.tar.gz: src/main/java/eu/unicore/gateway/properties/SecurityProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.util.HashSet;
import java.util.Set;

import org.apache.log4j.Logger;

import eu.unicore.gateway.util.LogUtil;
import eu.unicore.gateway.util.TruststoreUtil;
import eu.unicore.security.util.KeystoreChecker;

public class SecurityProperties extends RProperties
{
	private static final Logger log = LogUtil.getLogger(LogUtil.GATEWAY,
		SecurityProperties.class);

	public static final File FILE_SECURITY_PROPERTIES = new File("conf"
		+ File.separator + "security.properties");

	public static final String KEY_KEYSTORE = "keystore";
	public static final String KEY_TRUSTSTORE = "truststore";
	public static final String KEY_TRUSTSTORETYPE = "truststoretype";
	public static final String KEY_KEYSTORE_PWD = "keystorepassword";
	public static final String KEY_TRUSTSTORE_PWD = "truststorepassword";
	public static final String KEY_KEYSTORE_ALIAS = "keystorealias";

	private static final Set<String> REQ_PROPERTIES = new HashSet<String>();
	static 
	{
		REQ_PROPERTIES.add(KEY_KEYSTORE);
		REQ_PROPERTIES.add(KEY_KEYSTORE_PWD);
		REQ_PROPERTIES.add(KEY_TRUSTSTORE);
		REQ_PROPERTIES.add(KEY_TRUSTSTORE_PWD);
	}

	public SecurityProperties(String name)
	{
		super(name, REQ_PROPERTIES);
	}

	public SecurityProperties(File f)
	{
		super(f, REQ_PROPERTIES);
	}

	public String getKeystore()
	{
		return this.getStringProperty(KEY_KEYSTORE);
	}

	public String getKeystorePassword()
	{
		return this.getStringProperty(KEY_KEYSTORE_PWD);
	}

	public String getKeystoreType()
	{
		return keytype(getKeystore());
	}

	public String getTruststore()
	{
		return this.getStringProperty(KEY_TRUSTSTORE);
	}

	public String getTruststorePassword()
	{
		return this.getStringProperty(KEY_TRUSTSTORE_PWD);
	}

	public String getTruststoreType()
	{
		String type=this.getStringProperty(KEY_TRUSTSTORETYPE);
		if(type!=null)return type;
		//else autodetect...
		return keytype(getTruststore());
	}

	public String getKeystoreAlias()
	{
		// the default value can be null. In such a case the keystore handling code 
		// will try to guess the alias.
		return this.getStringProperty(KEY_KEYSTORE_ALIAS, null);
	}

	private static String keytype(String n)
	{
		log.info("keystore type of :" + n);

		if (n.endsWith(".p12"))
			return "PKCS12";
		else if (n.endsWith(".jks"))
			return "JKS";
		throw new RuntimeException(
			"The keystore file must have the extension '.p12' or '.jks'");
	}

	/**
	 * Checks if keystore and trustore are defined, can be opened. Whether
	 * key alias is valid, or if default alias can be established.
	 * @throws Exception
	 */
	public void validate() throws Exception
	{
		String file = getKeystore();
		String password = getKeystorePassword();
		String type = getKeystoreType();
		String alias = getKeystoreAlias();
		
		KeystoreChecker.validateKeystore(file, password, password, type, alias);
		
		file = getTruststore();
		password = getTruststorePassword();
		type = getTruststoreType();
		if (password == null || password.equals(""))
			throw new Exception("Truststore password can not be empty. " +
					"Unfortunately many libraries does not allow for this. " +
					"Please set in on your keystore and in your configuration.");

		if (type.equalsIgnoreCase("JKS") || type.equalsIgnoreCase("pkcs12"))
		{
			KeyStore ks = KeyStore.getInstance(type);
			InputStream is = new BufferedInputStream(new FileInputStream(file));
			ks.load(is, password.toCharArray());
			is.close();
		} else if ("file".equalsIgnoreCase(type))
		{
			TruststoreUtil.loadTruststoreFromPemFile(file);
		} else if (type.startsWith("dir"))
		{
			TruststoreUtil.loadTruststoreFromDirectory(file);
		} else
			throw new KeyStoreException("Truststore type " + type + " is unknown.");
	}
}

==> unicore-gateway6-4.2.0-0.src.tar.gz: src/main/java/eu/unicore/gateway/properties/SecurityProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import org.apache.log4j.Logger;

import eu.unicore.gateway.util.LogUtil;
import eu.unicore.security.util.KeystoreChecker;

public class SecurityProperties extends RProperties
{
	private static final Logger log = LogUtil.getLogger(LogUtil.GATEWAY,
		SecurityProperties.class);

	public static final File FILE_SECURITY_PROPERTIES = new File("conf"
		+ File.separator + "security.properties");

	public static final String KEY_KEYSTORE = "keystore";
	public static final String KEY_TRUSTSTORE = "truststore";
	public static final String KEY_TRUSTSTORETYPE = "truststoretype";
	public static final String KEY_KEYSTORE_PWD = "keystorepassword";
	public static final String KEY_TRUSTSTORE_PWD = "truststorepassword";
	public static final String KEY_KEYSTORE_ALIAS = "keystorealias";

	private static final Set<String> REQ_PROPERTIES = new HashSet<String>();
	static 
	{
		REQ_PROPERTIES.add(KEY_KEYSTORE);
		REQ_PROPERTIES.add(KEY_KEYSTORE_PWD);
		REQ_PROPERTIES.add(KEY_TRUSTSTORE);
		REQ_PROPERTIES.add(KEY_TRUSTSTORE_PWD);
	}

	public SecurityProperties(String name)
	{
		super(name, REQ_PROPERTIES);
	}

	public SecurityProperties(File f)
	{
		super(f, REQ_PROPERTIES);
	}

	public String getKeystore()
	{
		return this.getStringProperty(KEY_KEYSTORE);
	}

	public String getKeystorePassword()
	{
		return this.getStringProperty(KEY_KEYSTORE_PWD);
	}

	public String getKeystoreType()
	{
		return keytype(getKeystore());
	}

	public String getTruststore()
	{
		return this.getStringProperty(KEY_TRUSTSTORE);
	}

	public String getTruststorePassword()
	{
		return this.getStringProperty(KEY_TRUSTSTORE_PWD);
	}

	public String getTruststoreType()
	{
		String type=this.getStringProperty(KEY_TRUSTSTORETYPE);
		if(type!=null)return type;
		String tStore=getTruststore();
		File f=new File(tStore);
		if(new File(tStore).isDirectory())return "directory";
		else if(f.getName().endsWith(".pem"))return "file";
		//else p12 or jks
		return keytype(getTruststore());
	}

	public String getKeystoreAlias()
	{
		// the default value can be null. In such a case the keystore handling code 
		// will try to guess the alias.
		return this.getStringProperty(KEY_KEYSTORE_ALIAS, null);
	}

	private static String keytype(String n)
	{
		log.info("keystore type of :" + n);
                String name=n.toLowerCase();
		if (name.endsWith(".p12") || name.endsWith(".pfx"))
			return "PKCS12";
		else if (name.endsWith(".jks"))
			return "JKS";
		throw new RuntimeException(
			"The keystore file must have the extension '.p12', '.pfx' or '.jks'");
	}

	/**
	 * Checks if keystore and trustore are defined, can be opened. Whether
	 * key alias is valid, or if default alias can be established.
	 * @throws Exception
	 */
	public void validate() throws Exception
	{
		String file = getKeystore();
		String password = getKeystorePassword();
		String type = getKeystoreType();
		String alias = getKeystoreAlias();
		
		KeystoreChecker.validateKeystore(file, password, password, type, alias);
		
		file = getTruststore();
		password = getTruststorePassword();
		type = getTruststoreType();
		
		KeystoreChecker.validateTruststore(file, password, type);
	}
}
